Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(360)

Unified Diff: webrtc/api/ortc/ortcfactoryinterface.h

Issue 2981513002: Wire up RTP keep-alive in ortc api. (Closed)
Patch Set: Moved RtcpParameters into RtpTransportParameters Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | webrtc/api/ortc/rtptransportinterface.h » ('j') | webrtc/api/ortc/rtptransportinterface.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/api/ortc/ortcfactoryinterface.h
diff --git a/webrtc/api/ortc/ortcfactoryinterface.h b/webrtc/api/ortc/ortcfactoryinterface.h
index 4f0a9beb133a4391ddd1ed213441d37a772d9e06..5d4dbfe832be3bc9fc9fc0b49b72fc3420570deb 100644
--- a/webrtc/api/ortc/ortcfactoryinterface.h
+++ b/webrtc/api/ortc/ortcfactoryinterface.h
@@ -115,14 +115,14 @@ class OrtcFactoryInterface {
// |rtp| can't be null. |rtcp| must be non-null if and only if
// |rtcp_parameters.mux| is false, indicating that RTCP muxing isn't used.
// Note that if RTCP muxing isn't enabled initially, it can still enabled
// later through SetRtcpParameters.
Taylor Brandstetter 2017/07/17 23:13:11 The method ended up just being called SetParameter
ilnik 2017/07/21 12:21:19 Done.
//
// If |transport_controller| is null, one will automatically be created, and
// its lifetime managed by the returned RtpTransport. This should only be
// done if a single RtpTransport is being used to communicate with the remote
// endpoint.
virtual RTCErrorOr<std::unique_ptr<RtpTransportInterface>> CreateRtpTransport(
- const RtcpParameters& rtcp_parameters,
+ const RtpTransportParameters& rtcp_parameters,
Taylor Brandstetter 2017/07/17 23:13:11 Need to replace "rtcp_parameters" with "rtp_parame
ilnik 2017/07/21 12:21:19 Done.
PacketTransportInterface* rtp,
PacketTransportInterface* rtcp,
RtpTransportControllerInterface* transport_controller) = 0;
@@ -130,7 +130,7 @@ class OrtcFactoryInterface {
// Creates an SrtpTransport which is an RTP transport that uses SRTP.
virtual RTCErrorOr<std::unique_ptr<SrtpTransportInterface>>
CreateSrtpTransport(
- const RtcpParameters& rtcp_parameters,
+ const RtpTransportParameters& rtcp_parameters,
PacketTransportInterface* rtp,
PacketTransportInterface* rtcp,
RtpTransportControllerInterface* transport_controller) = 0;
@@ -115,14 +115,14 @@ class OrtcFactoryInterface {
// |rtcp_parameters.mux| is false, indicating that RTCP muxing isn't used.
// Note that if RTCP muxing isn't enabled initially, it can still enabled
- // later through SetRtcpParameters.
+ // later through SetRtpTransportParameters.
Taylor Brandstetter 2017/07/17 23:13:11 The method ended up just being called SetParameter
ilnik 2017/07/21 12:21:19 Done.
« no previous file with comments | « no previous file | webrtc/api/ortc/rtptransportinterface.h » ('j') | webrtc/api/ortc/rtptransportinterface.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698